Profile enum

Internal terminal color profile representation.

This mirrors the upstream charmbracelet/colorprofile model:

  • noTty: no ANSI output should be emitted (strip all escapes)
  • ascii: no colors, but text decorations may be used
  • ansi/ansi256/trueColor: progressively richer color support
Inheritance
Available extensions

Values

unknown → const Profile
noTty → const Profile
ascii → const Profile
ansi → const Profile
ansi256 → const Profile
trueColor → const Profile

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator <(Profile other) bool

Available on Profile, provided by the ProfileOrdering extension

operator <=(Profile other) bool

Available on Profile, provided by the ProfileOrdering extension

operator ==(Object other) bool
The equality operator.
inherited
operator >(Profile other) bool

Available on Profile, provided by the ProfileOrdering extension

operator >=(Profile other) bool

Available on Profile, provided by the ProfileOrdering extension

Constants

values → const List<Profile>
A constant List of the values in this enum, in order of their declaration.