input library Ultraviolet
Typed terminal events, input decoding, and input stream utilities.
Classes
- BackgroundColorEvent
- Background color report.
- BlurEvent
- Terminal focus lost event.
- CancelReader
- CancelReader provides a cancelable reader interface.
- CapabilityEvent
- Capability string event (e.g., terminal features).
- CellSizeEvent
- Reports terminal cell size in pixels.
- ClipboardEvent
- Clipboard selection and content (OSC 52).
- ClipboardSelection
- ColorPaletteEvent
- Palette color report for an index.
- CursorColorEvent
- Cursor color report.
- CursorPositionEvent
- Reports cursor position.
- DarkColorSchemeEvent
- Terminal reports dark color scheme preference.
- Environ
-
An environment snapshot represented as
KEY=valuestrings. - Event
- Base type for UV-style input events.
- EventDecoder
- A high-performance ANSI input decoder.
- FocusEvent
- Terminal focus gained event.
- ForegroundColorEvent
- Foreground color report.
- IgnoredEvent
- Internal marker for sequences intentionally ignored.
- Key
- UV-style key event.
- KeyboardEnhancementsEvent
- Kitty keyboard enhancements support report.
- KeyEvent
- Base type for key press/release events.
- KeyMod
- Modifier keys.
- KeyPressEvent
- Key press event.
- KeyReleaseEvent
- Key release event.
- KittyGraphicsEvent
-
Kitty graphics payload (APC
G ... ST). - KittyOptions
- Options parsed from a Kitty graphics report.
- LegacyKeyEncoding
- Legacy key encoding behavior flags.
- LightColorSchemeEvent
- Terminal reports light color scheme preference.
- Logger
- Logger is a simple logger interface for Ultraviolet internals.
- ModeReportEvent
- Terminal mode report.
- ModifyOtherKeysEvent
- Xterm ModifyOtherKeys mode report.
- Mouse
- Mouse event payload.
- MouseButton
- Mouse button codes (X11-style).
- MouseClickEvent
- Mouse click event.
- MouseEvent
- Base type for mouse click/release/wheel/motion events.
- MouseMotionEvent
- Mouse motion (move/drag) event.
- MouseReleaseEvent
- Mouse button release event.
- MouseWheelEvent
- Mouse wheel (scroll) event.
- MultiEvent
- Aggregates multiple events decoded from a single input.
- NullLogger
- A logger that does nothing.
- PasteEndEvent
- Bracketed paste end.
- PasteEvent
- Bracketed paste content.
- PasteStartEvent
- Bracketed paste start.
- PrimaryDeviceAttributesEvent
- Primary device attributes (DA1) report.
- SecondaryDeviceAttributesEvent
- Secondary device attributes (DA2) report.
- Size
- Reports terminal size in cells and optional pixels.
- SizeNotifier
- Stub SizeNotifier for platforms without SIGWINCH.
- TabStops
- Tab stop management.
- TerminalReader
- TerminalReader represents an input event loop that reads input events from a reader and parses them into human-readable events.
- TerminalVersionEvent
-
Terminal version string (e.g.,
xterm-kitty 0.32.0). - TertiaryDeviceAttributesEvent
- Tertiary device attributes (DA3) report.
- UnknownApcEvent
- Unknown APC event with raw payload.
- UnknownCsiEvent
- Unknown CSI event with raw payload.
- UnknownDcsEvent
- Unknown DCS event with raw payload.
- UnknownEvent
- Unknown event with raw payload.
- UnknownOscEvent
- Unknown OSC event with raw payload.
- UnknownPmEvent
- Unknown PM event with raw payload.
- UnknownSosEvent
- Unknown SOS event with raw payload.
- UnknownSs3Event
- Unknown SS3 event with raw payload.
- UvEventStreamParser
- Streaming UV event scanner with ESC-timeout compatibility.
- WindowOpEvent
- Window operation report (OSC 7/11/… payloads).
- WindowPixelSizeEvent
- Reports window size in pixels.
- WindowSizeEvent
- Reports window size in cells and optional pixels.
Enums
- ModeSetting
- MouseMode
- Mouse mode.
Constants
- defaultEscTimeout → const Duration
- Default timeout at which the TerminalReader will process ESC sequences.
- keyBackspace → const int
- keyBegin → const int
- keyCapsLock → const int
- keyDelete → const int
- keyDown → const int
- keyEnd → const int
- keyEnter → const int
- keyEscape → const int
- keyExtended → const int
- keyF1 → const int
- keyF10 → const int
- keyF11 → const int
- keyF12 → const int
- keyF13 → const int
- keyF14 → const int
- keyF15 → const int
- keyF16 → const int
- keyF17 → const int
- keyF18 → const int
- keyF19 → const int
- keyF2 → const int
- keyF20 → const int
- keyF21 → const int
- keyF22 → const int
- keyF23 → const int
- keyF24 → const int
- keyF25 → const int
- keyF26 → const int
- keyF27 → const int
- keyF28 → const int
- keyF29 → const int
- keyF3 → const int
- keyF30 → const int
- keyF31 → const int
- keyF32 → const int
- keyF33 → const int
- keyF34 → const int
- keyF35 → const int
- keyF36 → const int
- keyF37 → const int
- keyF38 → const int
- keyF39 → const int
- keyF4 → const int
- keyF40 → const int
- keyF41 → const int
- keyF42 → const int
- keyF43 → const int
- keyF44 → const int
- keyF45 → const int
- keyF46 → const int
- keyF47 → const int
- keyF48 → const int
- keyF49 → const int
- keyF5 → const int
- keyF50 → const int
- keyF51 → const int
- keyF52 → const int
- keyF53 → const int
- keyF54 → const int
- keyF55 → const int
- keyF56 → const int
- keyF57 → const int
- keyF58 → const int
- keyF59 → const int
- keyF6 → const int
- keyF60 → const int
- keyF61 → const int
- keyF62 → const int
- keyF63 → const int
- keyF7 → const int
- keyF8 → const int
- keyF9 → const int
- keyFind → const int
- keyHome → const int
- keyInsert → const int
- keyIsoLevel3Shift → const int
- keyIsoLevel5Shift → const int
- keyKp0 → const int
- keyKp1 → const int
- keyKp2 → const int
- keyKp3 → const int
- keyKp4 → const int
- keyKp5 → const int
- keyKp6 → const int
- keyKp7 → const int
- keyKp8 → const int
- keyKp9 → const int
- keyKpBegin → const int
- keyKpComma → const int
- keyKpDecimal → const int
- keyKpDelete → const int
- keyKpDivide → const int
- keyKpDown → const int
- keyKpEnd → const int
- keyKpEnter → const int
- keyKpEqual → const int
- keyKpHome → const int
- keyKpInsert → const int
- keyKpLeft → const int
- keyKpMinus → const int
- keyKpMultiply → const int
- keyKpPgDown → const int
- keyKpPgUp → const int
- keyKpPlus → const int
- keyKpRight → const int
- keyKpSep → const int
- keyKpUp → const int
- keyLeft → const int
- keyLeftAlt → const int
- keyLeftCtrl → const int
- keyLeftHyper → const int
- keyLeftMeta → const int
- keyLeftShift → const int
- keyLeftSuper → const int
- keyLowerVol → const int
- keyMediaFastForward → const int
- keyMediaNext → const int
- keyMediaPause → const int
- keyMediaPlay → const int
- keyMediaPlayPause → const int
- keyMediaPrev → const int
- keyMediaRecord → const int
- keyMediaReverse → const int
- keyMediaRewind → const int
- keyMediaStop → const int
- keyMenu → const int
- keyMute → const int
- keyNumLock → const int
- keyPause → const int
- keyPgDown → const int
- keyPgUp → const int
- keyPrintScreen → const int
- keyRaiseVol → const int
- keyRight → const int
- keyRightAlt → const int
- keyRightCtrl → const int
- keyRightHyper → const int
- keyRightMeta → const int
- keyRightShift → const int
- keyRightSuper → const int
- keyScrollLock → const int
- keySelect → const int
- keySpace → const int
- keyTab → const int
- keyUp → const int
Functions
-
buildKeysTable(
LegacyKeyEncoding flags, String term, {bool useTerminfo = false}) → Map< String, Key> - Builds a table of key sequences and their corresponding key events.
-
keyModFromXTerm(
int xtermModMinus1) → int -
Converts a 1-based XTerm modifier value to a UV
KeyModbitmask.