CanvasTerminalRenderer class final
Renders a UV Buffer to an HTML5 Canvas 2D context.
Each cell in the buffer is drawn as a filled background rectangle plus a text glyph. Supports foreground/background colors (16-color, 256-color, true color), bold, italic, faint, underline, and strikethrough.
Constructors
- CanvasTerminalRenderer(CanvasRenderingContext2D context, {double fontSize = 14, String fontFamily = 'monospace'})
Properties
- cellHeight → double
-
no setter
- cellWidth → double
-
no setter
- context → CanvasRenderingContext2D
-
final
- fontFamily → String
-
final
- fontSize → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastFlushedOutput → String
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
configureViewport(
{required double width, required double height, double devicePixelRatio = 1.0}) → void - Configures the logical viewport size and backing-store scale.
-
disableBracketedPaste(
) → void -
inherited
-
disableFocusReporting(
) → void -
inherited
-
disableMouseAllEvents(
) → void -
inherited
-
enableBracketedPaste(
) → void -
inherited
-
enableFocusReporting(
) → void -
inherited
-
enableMouseAllEvents(
) → void -
inherited
-
enterAltScreen(
) → void -
inherited
-
erase(
) → void -
inherited
-
exitAltScreen(
) → void -
inherited
-
flush(
) → void -
height(
) → int -
hideCursor(
) → void -
inherited
-
measureFont(
) → void - Measure font metrics so cells are sized correctly.
-
moveTo(
int x, int y) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
popKeyboardEnhancements(
) → void -
inherited
-
prependString(
Buffer newbuf, String str) → void -
inherited
-
pushKeyboardEnhancements(
int flags) → void -
inherited
-
queryBackgroundColor(
) → void -
inherited
-
queryColorScheme(
) → void -
inherited
-
queryCursorColor(
) → void -
inherited
-
queryForegroundColor(
) → void -
inherited
-
queryKeyboardEnhancements(
) → void -
inherited
-
queryKittyGraphics(
) → void -
inherited
-
queryPrimaryDeviceAttributes(
) → void -
inherited
-
querySecondaryDeviceAttributes(
) → void -
inherited
-
queryTerminalVersion(
) → void -
inherited
-
queryTertiaryDeviceAttributes(
) → void -
inherited
-
render(
Buffer buf) → void -
resize(
int cols, int rows) → void -
setBackspace(
bool v) → void -
inherited
-
setColorProfile(
Profile profile) → void -
inherited
-
setFullscreen(
bool v) → void -
inherited
-
setHasTab(
bool v) → void -
inherited
-
setLogger(
void logger(String message)?) → void -
inherited
-
setRelativeCursor(
bool v) → void -
inherited
-
setScrollOptim(
bool v) → void -
inherited
-
setSynchronizedOutput(
bool v) → void -
inherited
-
setTabStops(
int width) → void -
inherited
-
showCursor(
) → void -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
width(
) → int -
writeString(
String s) → int -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited